@@ -11,20 +11,20 @@ use File::Path   2.04 ();
 use File::Basename  0 ();
 use Params::Util 0.33 ();
 use DBI         1.607 ();
-use DBD::SQLite  1.25 ();
+use DBD::SQLite  1.27 ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.28';
+	$VERSION = '1.30';
 }
 
 # Support for the 'prune' option
 my @PRUNE = ();
 END {
-	foreach ( @PRUNE ) {
+	foreach ( reverse @PRUNE ) {
 		next unless -e $_;
 		require File::Remove;
-		File::Remove::remove($_);
+		File::Remove::remove( \1, $_ );
 	}
 }
 
@@ -101,7 +101,10 @@ sub import {
 	my $pkg      = $params{package};
 	my $readonly = $params{readonly};
 	my $dsn      = "dbi:SQLite:$file";
-	my $dbh      = DBI->connect($dsn);
+	my $dbh      = DBI->connect( $dsn, undef, undef, {
+		PrintError => 0,
+		RaiseError => 1,
+	} );
 
 	# Schema creation support
 	if ( $created and Params::Util::_CODELIKE($params{create}) ) {
@@ -111,7 +114,7 @@ sub import {
 	# Check the schema version before generating
 	my $version  = $dbh->selectrow_arrayref('pragma user_version')->[0];
 	if ( exists $params{user_version} and $version != $params{user_version} ) {
-		die "Schema user_version mismatch (got $version, wanted $params{user_version})";
+		Carp::croak("Schema user_version mismatch (got $version, wanted $params{user_version})");
 	}
 
 	# Generate the support package code
@@ -131,13 +134,14 @@ sub sqlite { '$file' }
 sub dsn { '$dsn' }
 
 sub dbh {
-	\$DBH or
-	\$_[0]->connect or
-	Carp::croak("connect: \$DBI::errstr");
+	\$DBH or \$_[0]->connect;
 }
 
 sub connect {
-	DBI->connect(\$_[0]->dsn);
+	DBI->connect( \$_[0]->dsn, undef, undef, {
+		PrintError => 0,
+		RaiseError => 1,
+	} );
 }
 
 sub prepare {
@@ -194,8 +198,7 @@ END_PERL
 	$code .= <<"END_PERL" unless $readonly;
 sub begin {
 	\$DBH or
-	\$DBH = \$_[0]->connect or
-	Carp::croak("connect: \$DBI::errstr");
+	\$DBH = \$_[0]->connect;
 	\$DBH->begin_work;
 }
 
@@ -260,6 +263,7 @@ END_PERL
 
 			# Discover the primary key
 			@{$table->{pk}}  = map($_->{name}, grep { $_->{pk} } @columns);
+			$table->{pks}    = scalar(@{$table->{pk}});
 
 			# What will be the class for this table
 			$table->{class}  = ucfirst lc $table->{name};
@@ -276,6 +280,7 @@ END_PERL
 				"insert into $table->{name}" .
 				"( $table->{sql}->{cols} )"  .
 				" values ( $table->{sql}->{vals} )";
+			$sql->{where_pk}    = join(' and ', map("$_ = ?", @{$table->{pk}}))
 		}
 
 		# Generate the foreign key metadata
@@ -343,17 +348,34 @@ sub iterate {
 
 END_PERL
 
+			# Add the primary key based single object loader
+			if ( $table->{pks} ) {
+				$code .= <<"END_PERL";
+sub load {
+	my \$class = shift;
+	my \$row   = $pkg->selectrow_hashref(
+		'$sql->{select} where $sql->{where_pk}',
+		undef, \@_,
+	);
+	unless ( \$row ) {
+		Carp::croak("$table->{class} row does not exist");
+	}
+	bless( \$row, '$table->{class}' );
+}
+
+END_PERL
+			}
+
 			# Generate the elements for tables with primary keys
 			if ( defined $table->{pk} and ! $readonly ) {
 				my $nattr = join "\n", map { "\t\t$_ => \$attr{$_}," } @names;
 				my $iattr = join "\n", map { "\t\t\$self->{$_},"       } @names;
 				my $fill_pk = scalar @{$table->{pk}} == 1 
-					    ? "\t\$self->{$table->{pk}->[0]} = \$dbh->func('last_insert_rowid') unless \$self->{$table->{pk}->[0]};"
-					    : q{};
+					? "\t\$self->{$table->{pk}->[0]} = \$dbh->func('last_insert_rowid') unless \$self->{$table->{pk}->[0]};"
+					: q{};
 				my $where_pk      = join(' and ', map("$_ = ?", @{$table->{pk}}));
-				my $where_pk_attr = join("\n", map("\t\t\$self->{$_},", @{$table->{pk}}));				
+				my $where_pk_attr = join("\n", map("\t\t\$self->{$_},", @{$table->{pk}}));
 				$code .= <<"END_PERL";
-
 sub new {
 	my \$class = shift;
 	my \%attr  = \@_;
@@ -759,7 +781,7 @@ L<ORLite::Mirror>, L<ORLite::Migrate>
 
 =head1 COPYRIGHT
 
-Copyright 2008 - 2009 Adam Kennedy.
+Copyright 2008 - 2010 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
